==> velobox_update_3.0.7.tar.gz: usr/local/vmkstationd_V3.3.0/htdocs/production/js/dashboard.js <==
/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
// SATTELDRUCK
//const host_s = `http://${location.host}`;
//const ws_s = host_s.replace('http','ws');
//const apps_s = "satteldruckanalyse";

//HOCKER
var ws_h = `ws://${script_setting.smartcube}/messages`;

let con_img = document.getElementById("img_Seatbonemeasurement");
let link_sitzknochen = document.getElementById("Seatbonemeasurement");
var wsH = {};
let side_smartcube = document.getElementById('sitzknochen-menu');


/* The code block is creating a setInterval function that runs every 1000 milliseconds (1 second).
Inside the function, it checks if the variable `hocker` is not null. If `hocker` is not null, it
creates a new WebSocket connection using the `ws_h` URL and the protocols "soap" and "wamp". */
let inter_Seatbonemeasurement = setInterval( () => {
  document.getElementById('Seatbonemeasurement').classList.remove('no-hocker')
  document.getElementById('img_Seatbonemeasurement').classList.remove('uk-blend-luminosity')
  console.log(`%c serch SmartCube: ${script_setting.smartcube}`,'background: #222;color: #5cbc40;padding:1em');
  if(script_setting.smartcube){
    ws_h = `ws://${script_setting.smartcube}/messages`;
    wsH = new WebSocket(ws_h, ["soap", "wamp"]);
  
    wsH.onopen = (event) =>{
      localStorage.setItem('smartcube_link',true)
      console.log(`%c SmartCube found`,'background: #5cbc40;color: #222;padding:1em;font-size:1.5em');
      document.getElementById('Seatbonemeasurement').classList.remove('no-hocker')
      document.getElementById('img_Seatbonemeasurement').classList.remove('uk-blend-luminosity')
    }
  }
  clearInterval(inter_Seatbonemeasurement);
}, 1000);


browser()

function browser(){
  let ele = document.getElementById('browser')
  let os_browser = navigator.userAgent

  if(os_browser.includes('Win64') && os_browser.includes('Firefox')){
    ele.removeAttribute('class')
  }
  
}



function noHocker() {
  //console.log(link_sitzknochen,con_img,side_smartcube);
  //link_sitzknochen.classList.add("no-hocker");
  //con_img.classList.add('uk-blend-luminosity');
  //link_sitzknochen.setAttribute("onclick", 'LinkTo("system.tcls#smartcube")');
  //side_smartcube.setAttribute('href','/production/system.tcls');
  //localStorage.setItem('hocker',"off");
}

localStorage.removeItem('product1');
localStorage.removeItem('product2');
localStorage.removeItem('session_note');
localStorage.removeItem('session');
localStorage.removeItem('client_info');
localStorage.removeItem('client_id');
localStorage.removeItem('client_mail');
localStorage.removeItem('client_name');
localStorage.removeItem('note_session');

==> velobox_update_3.1.2.tar.gz: usr/local/vmkstationd_V3.4.0/htdocs/production/js/dashboard.js <==
/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
// SATTELDRUCK
//const host_s = `http://${location.host}`;
//const ws_s = host_s.replace('http','ws');
//const apps_s = "satteldruckanalyse";

//HOCKER
var ws_h = `ws://${script_setting.smartcube}/messages`;

let con_img = document.getElementById("img_Seatbonemeasurement");
let link_sitzknochen = document.getElementById("Seatbonemeasurement");
var wsH = {};
let side_smartcube = document.getElementById('sitzknochen-menu');
saveToLocalStorage('tpfs','sattel')
/* The code block is creating a setInterval function that runs every 1000 milliseconds (1 second).
Inside the function, it checks if the variable `hocker` is not null. If `hocker` is not null, it
creates a new WebSocket connection using the `ws_h` URL and the protocols "soap" and "wamp". */
let inter_Seatbonemeasurement = setInterval( () => {
  document.getElementById('Seatbonemeasurement').classList.remove('no-hocker')
  document.getElementById('img_Seatbonemeasurement').classList.remove('uk-blend-luminosity')
  console.log(`%c serch SmartCube: ${script_setting.smartcube}`,'background: #222;color: #5cbc40;padding:1em');
  if(script_setting.smartcube){
    ws_h = `ws://${script_setting.smartcube}/messages`;
    wsH = new WebSocket(ws_h, ["soap", "wamp"]);
  
    wsH.onopen = (event) =>{
      saveToLocalStorage('smartcube_link',true)
      console.log(`%c SmartCube found`,'background: #5cbc40;color: #222;padding:1em;font-size:1.5em');
      document.getElementById('Seatbonemeasurement').classList.remove('no-hocker')
      document.getElementById('img_Seatbonemeasurement').classList.remove('uk-blend-luminosity')
    }
  }
  clearInterval(inter_Seatbonemeasurement);
}, 1000);


browser()

function browser(){
  let ele = document.getElementById('browser')
  let os_browser = navigator.userAgent

  if(os_browser.includes('Win64') && os_browser.includes('Firefox')){
    ele.removeAttribute('class')
  }
  
}



function noHocker() {
  //console.log(link_sitzknochen,con_img,side_smartcube);
  //link_sitzknochen.classList.add("no-hocker");
  //con_img.classList.add('uk-blend-luminosity');
  //link_sitzknochen.setAttribute("onclick", 'LinkTo("system.tcls#smartcube")');
  //side_smartcube.setAttribute('href','/production/system.tcls');
  //saveToLocalStorage('hocker',"off");
}

let remove_items = ['product1','product2','session_note','session','client_info','client_id','client_mail','client_name','note_session','client_fc','client_forenames','client_surename','devLang','SelCat','sk','sessionID'];

clearFromLocalStorage(remove_items)


//const shortcuts = {
//  n: () => LinkTo('newclient.tcls?check=true'),
//  c: () => LinkTo('clients.tcls?check=true'),
//  l: () => mod_log()
//};

//document.addEventListener('keydown', (event) => {
//  // Prüfen, ob das aktive Element ein Input- oder Textarea-Feld ist
//  const activeElement = document.activeElement;
//  const isInputFieldActive = activeElement.tagName === 'INPUT' || activeElement.tagName === 'TEXTAREA';
  
//  if (!isInputFieldActive) {
//    const key = event.key.toLowerCase();
//    if (shortcuts[key]) {
//      shortcuts[key]();
//    }
//  }
//});

/* The `document.addEventListener('keydown', (event) => { ... });` block of code is adding an event
//listener to the document object that listens for keydown events. When a keydown event occurs, the
//provided callback function is executed. */
//document.addEventListener('keydown', (event) => {
//  if (event.key === 'n' || event.key === 'N') {
//      LinkTo('newclient.tcls?check=true');
//  }
//  if (event.key === 'c' || event.key === 'C'){
//      LinkTo('clients.tcls?check=true')
//  }
//  if (event.key === 'l' || event.key === 'L'){
//      mod_log()
//  }
//});
